pub enum BenchmarkArgs {
Array(BenchmarkArgSpec),
ScalarArray(BenchmarkArgSpec, BenchmarkArgSpec),
ArrayScalar(BenchmarkArgSpec, BenchmarkArgSpec),
ArrayArray(BenchmarkArgSpec, BenchmarkArgSpec),
ArrayScalarScalar(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec),
ArrayArrayScalar(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec),
ArrayArrayArray(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec),
ArrayArrayArrayArray(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec),
}Expand description
Specification for benchmark arguments
This provides a concise definition of function input based on a combination of scalar/array arguments each specified by a BenchmarkArgSpec.
Variants
Array(BenchmarkArgSpec)
Invoke a unary function with array input
ScalarArray(BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a binary function with scalar and array input
ArrayScalar(BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a binary function with array and scalar input
ArrayArray(BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a binary function with two arrays
ArrayScalarScalar(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a function with an array and two scalar inputs
ArrayArrayScalar(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a ternary function with two arrays and a scalar
ArrayArrayArray(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a ternary function with three arrays
ArrayArrayArrayArray(BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec, BenchmarkArgSpec)
Invoke a quaternary function with four arrays
Implementations
Sourceimpl BenchmarkArgs
impl BenchmarkArgs
Sourcepub fn build_data(
&self,
num_batches: usize,
rows_per_batch: usize,
) -> Result<BenchmarkData>
pub fn build_data( &self, num_batches: usize, rows_per_batch: usize, ) -> Result<BenchmarkData>
Build BenchmarkData with the specified number of batches