pub struct BenchmarkData { /* private fields */ }Expand description
Fully resolved data ready for running a benchmark
This struct contains the fully built data (such that benchmarks do not measure the time required to build the data) and has methods for invoking functions on it.
Implementations
Sourceimpl BenchmarkData
impl BenchmarkData
Sourcepub fn make_label(&self, lib: &str, name: &str) -> String
pub fn make_label(&self, lib: &str, name: &str) -> String
Create a label based on the library, function name, and configuration
Sourcepub fn invoke_scalar(&self, udf: &ScalarUDF) -> Result<()>
pub fn invoke_scalar(&self, udf: &ScalarUDF) -> Result<()>
Invoke a scalar function on this data
Sourcepub fn invoke_aggregate(&self, udf: &AggregateUDF) -> Result<ScalarValue>
pub fn invoke_aggregate(&self, udf: &AggregateUDF) -> Result<ScalarValue>
Invoke an aggregate function on this data