assert_value_equal

Function assert_value_equal 

pub fn assert_value_equal(actual: &ColumnarValue, expected: &ColumnarValue)
Assert two ColumnarValues are equal

Panics if the values’ Scalar/Array status is different or if the content is not equal. This can be used in place of assert_eq!() to generate reasonable failure messages for geometry values where the default failure message would otherwise be uninformative.

This is intended to be used with create_array_value() functions for geometry types. It can be used with create_array!() and Arrow types as well; however, assert_eq!() is usually sufficient for those cases.