geoarrow_data_dir

Function geoarrow_data_dir 

pub fn geoarrow_data_dir() -> Result<String>
Find the most likely path to the geoarrow-data testing directory if it exists

This looks for a geoarrow-data checkout using the value of SEDONA_GEOARROW_DATA_DIR, the directory that would be valid if running cargo run from the repository root, or the directory that would be valid if running cargo test (in that order).