pub struct TestReadOptions {
pub sedona_type: SedonaType,
pub chunk_size: usize,
pub output_size: Option<usize>,
}Expand description
Options for test file readers
Fields
sedona_type: SedonaTypeType to use for geometry when reading test files
chunk_size: usizeChunk size to output when reading test files
output_size: Option<usize>Approximate number of rows
This number is approximate and the actual number will be obtained by either truncating the input or cycling through batches until at least this number is reached. If omitted, the entire test file will be read.
Implementations
Sourceimpl TestReadOptions
impl TestReadOptions
Sourcepub fn new(sedona_type: SedonaType) -> Self
pub fn new(sedona_type: SedonaType) -> Self
Create new options with defaults
Sourcepub fn with_output_size(self, output_size: usize) -> Self
pub fn with_output_size(self, output_size: usize) -> Self
Apply a target output size to these options