AggregateUdfTester

Struct AggregateUdfTester 

pub struct AggregateUdfTester { /* private fields */ }
Low-level tester for aggregate functions

This struct provides a means by which to run a simple check of an aggregate implementation by approximating one method DataFusion might use to perform the aggregation. Whereas DataFusion may arrange various calls to accumulate, state, and update_batch to optimize for different cases, this tester is always created by aggregating states that were in turn created from accumulating one batch.

This is not a replacement for testing at a higher level using DataFusion’s actual aggregate implementation but provides a useful mechanism to ensure all the pieces of an accumulator are plugged in.

Implementations

Source

impl AggregateUdfTester

pub fn new(udf: AggregateUDF, arg_types: Vec<SedonaType>) -> Self

Create a new tester

pub fn return_type(&self) -> Result<SedonaType>

Compute the return type

pub fn aggregate_wkt( &self, batches: Vec<Vec<Option<&str>>>, ) -> Result<ScalarValue>

Perform a simple aggregation using WKT as geometry input

pub fn aggregate(&self, batches: &Vec<ArrayRef>) -> Result<ScalarValue>

Perform a simple aggregation

Each batch in batches is accumulated with its own accumulator and serialized into its own state, after which the states are accumulated in batches of one. This has the effect of testing all the pieces of an aggregator in a somewhat configurable/predictable way.

pub fn aggregate_groups( &self, batches: &Vec<ArrayRef>, group_indices: Vec<usize>, opt_filter: Option<&Vec<bool>>, emit_sizes: Vec<usize>, ) -> Result<ArrayRef>

Perform a simple grouped aggregation

Each batch in batches is accumulated with its own groups accumulator and serialized into its own state, after which the state resulting from each batch is merged into the final groups accumulator. This has the effect of testing the pieces of a groups accumulator in a predictable/debug-friendly (if artificial) way.