pub fn assert_array_equal(actual: &ArrayRef, expected: &ArrayRef)Expand description
Assert two ArrayRefs are equal
Panics if the values’ length or types are different or if the content is otherwise not
equal. This can be used in place of assert_eq!() to generate reasonable
failure messages for geometry arrays where the default failure message would
otherwise be uninformative.