TestReadOptions

Struct TestReadOptions 

pub struct TestReadOptions {
    pub sedona_type: SedonaType,
    pub chunk_size: usize,
    pub output_size: Option<usize>,
}
Options for test file readers

Fields

sedona_type: SedonaType

Type to use for geometry when reading test files

chunk_size: usize

Chunk size to output when reading test files

output_size: Option<usize>

Approximate number of rows

This number is approximate and the actual number will be obtained by either truncating the input or cycling through batches until at least this number is reached. If omitted, the entire test file will be read.

Implementations

Source

impl TestReadOptions

pub fn new(sedona_type: SedonaType) -> Self

Create new options with defaults

pub fn with_output_size(self, output_size: usize) -> Self

Apply a target output size to these options